@@ -6,11 +6,12 @@ use base qw(
     Path::Class::File::Lockable
     Class::Accessor::Fast
 );
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 use Carp;
 use Data::Dump qw( dump );
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 __PACKAGE__->mk_accessors(qw( attrs content ext has_unsaved_changes ));
 
